@@ -277,15 +277,18 @@ crew_class_launcher <- R6::R6Class(
         (2L * as.integer(isTRUE(self$reset_packages))) +
         (4L * as.integer(isTRUE(self$reset_options))) +
         (8L * as.integer(isTRUE(self$garbage_collection)))
+      tls <- environment(mirai::daemons)$..[[self$name]]$tls
+      tls <- if_any(is.null(tls), tls, nanonext::weakref_value(tls))
       list(
         url = socket,
+        asyncdial = FALSE,
         maxtasks = self$tasks_max,
         idletime = self$seconds_idle * 1000,
         walltime = self$seconds_wall * 1000,
         timerstart = self$tasks_timers,
         exitlinger = self$seconds_exit * 1000,
         cleanup = cleanup,
-        asyncdial = FALSE
+        tls = tls
       )
     },
     #' @description Create a call to [crew_worker()] to
@@ -509,7 +512,7 @@ crew_class_launcher <- R6::R6Class(
       walk(x = self$backlogged(), f = self$launch)
       resolved <- self$resolved()
       active <- nrow(self$workers) - length(resolved)
-      deficit <- min(demand - active, length(resolved))
+      deficit <- min(length(resolved), max(0L, demand - active))
       walk(x = head(x = resolved, n = deficit), f = self$launch)
       invisible()
     },
