@@ -20,6 +20,8 @@ crew_controller_system2 <- function(
   workers = 1L,
   host = NULL,
   port = NULL,
+  tls_enable = TRUE,
+  tls_config = NULL,
   seconds_interval = 0.5,
   seconds_timeout = 10,
   seconds_launch = 30,
@@ -38,6 +40,8 @@ crew_controller_system2 <- function(
     workers = workers,
     host = host,
     port = port,
+    tls_enable = tls_enable,
+    tls_config = tls_config,
     seconds_interval = seconds_interval,
     seconds_timeout = seconds_timeout
   )
