@@ -331,3 +331,208 @@ crew_test("task collection and results stack work", {
   }
   x$terminate()
 })
+
+crew_test("controller map() works", {
+  skip_on_cran()
+  skip_on_os("windows")
+  x <- crew_controller_local(
+    workers = 1L,
+    seconds_idle = 360
+  )
+  on.exit({
+    x$terminate()
+    rm(x)
+    gc()
+    crew_test_sleep()
+  })
+  x$start()
+  f <- function(x, y) x + y
+  out <- x$map(
+    command = f(x, y) + a + b,
+    iterate = list(x = c(1L, 2L), y = c(3L, 4L)),
+    data = list(a = 5L),
+    globals = list(f = f, b = 6L)
+  )
+  x$terminate()
+  expect_null(x$error)
+  expect_true(tibble::is_tibble(out))
+  expect_equal(nrow(out), 2L)
+  expect_equal(colnames(out), monad_names)
+  expect_equal(out$name, c("1", "2"))
+  expect_equal(out$command, rep(NA_character_, 2L))
+  expect_equal(out$result, list(15L, 17L))
+  expect_true(all(out$seconds >= 0))
+  expect_true(is.integer(out$seed))
+  expect_true(anyDuplicated(out$seed) < 1L)
+  expect_equal(out$error, rep(NA_character_, 2L))
+  expect_equal(out$trace, rep(NA_character_, 2L))
+  expect_equal(out$warnings, rep(NA_character_, 2L))
+  expect_equal(out$worker, rep(1L, 2L))
+  expect_equal(out$launcher, rep(x$launcher$name, 2L))
+  expect_false(anyNA(out$instance))
+  sum <- x$summary()
+  expect_equal(sum$worker, 1L)
+  expect_equal(sum$tasks, 2L)
+  expect_equal(sum$errors, 0L)
+  expect_equal(sum$warnings, 0L)
+})
+
+crew_test("map() works with errors and names and command strings", {
+  skip_on_cran()
+  skip_on_os("windows")
+  x <- crew_controller_local(
+    workers = 1L,
+    seconds_idle = 360
+  )
+  on.exit({
+    x$terminate()
+    rm(x)
+    gc()
+    crew_test_sleep()
+  })
+  x$start()
+  f <- function(x, y) {
+    warning("message")
+    x + y
+  }
+  expect_silent(
+    x$map(
+      command = f(x, y) + a + b,
+      iterate = list(x = c(1L, 2L), y = c(3L, 4L), id = c("z", "w")),
+      data = list(a = 5L),
+      globals = list(f = f),
+      save_command = TRUE,
+      names = "id",
+      error = "silent",
+      verbose = FALSE
+    )
+  )
+  expect_null(x$error)
+  expect_error(
+    x$map(
+      command = f(x, y) + a + b,
+      iterate = list(x = c(1L, 2L), y = c(3L, 4L), id = c("z", "w")),
+      data = list(a = 5L),
+      globals = list(f = f),
+      save_command = TRUE,
+      names = "id",
+      error = "stop"
+    ),
+    class = "crew_error"
+  )
+  expect_true(is.data.frame(x$error))
+  expect_warning(
+    out <- x$map(
+      command = f(x, y) + a + b,
+      iterate = list(x = c(1L, 2L), y = c(3L, 4L), id = c("z", "w")),
+      data = list(a = 5L),
+      globals = list(f = f),
+      save_command = TRUE,
+      names = "id",
+      error = "warn"
+    ),
+    class = "crew_warning"
+  )
+  x$terminate()
+  expect_true(tibble::is_tibble(out))
+  expect_equal(nrow(out), 2L)
+  expect_equal(colnames(out), monad_names)
+  expect_equal(out$name, c("z", "w"))
+  expect_equal(out$command, rep("f(x, y) + a + b", 2L))
+  expect_equal(out$result, list(NA, NA))
+  expect_true(all(out$seconds >= 0))
+  expect_true(is.integer(out$seed))
+  expect_true(anyDuplicated(out$seed) < 1L)
+  expect_false(anyNA(out$error))
+  expect_false(anyNA(out$trace))
+  expect_false(anyNA(out$warnings))
+  expect_equal(out$worker, rep(1L, 2L))
+  expect_equal(out$launcher, rep(x$launcher$name, 2L))
+  expect_false(anyNA(out$instance))
+  sum <- x$summary()
+  expect_equal(sum$worker, 1L)
+  expect_equal(sum$tasks, 6L)
+  expect_equal(sum$errors, 6L)
+  expect_equal(sum$warnings, 6L)
+})
+
+crew_test("map() tasks attributed to correct workers", {
+  skip_on_cran()
+  skip_on_os("windows")
+  x <- crew_controller_local(
+    workers = 4L,
+    seconds_idle = 360
+  )
+  on.exit({
+    x$terminate()
+    rm(x)
+    gc()
+    crew_test_sleep()
+  })
+  x$start()
+  f <- function(x, y) {
+    warning("message")
+    Sys.sleep(0.25)
+    x + y
+  }
+  x$launcher$launch(index = 3L)
+  out <- x$map(
+    command = f(x, y) + a + b,
+    iterate = list(x = 1L, y = 3L, id = "z"),
+    data = list(a = 5L),
+    globals = list(f = f),
+    save_command = TRUE,
+    names = "id",
+    error = "silent"
+  )
+  sum <- x$summary()
+  expect_equal(sum$worker, seq_len(4L))
+  expect_equal(sum$tasks, c(0L, 0L, 1L, 0L))
+  expect_equal(
+    sum$seconds > sqrt(.Machine$double.eps),
+    c(FALSE, FALSE, TRUE, FALSE)
+  )
+  expect_equal(sum$errors, c(0L, 0L, 1L, 0L))
+  expect_equal(sum$warnings, c(0L, 0L, 1L, 0L))
+})
+
+crew_test("map() does not need an started controller", {
+  skip_on_cran()
+  skip_on_os("windows")
+  x <- crew_controller_local(
+    workers = 1L,
+    seconds_idle = 360
+  )
+  on.exit({
+    x$terminate()
+    rm(x)
+    gc()
+    crew_test_sleep()
+  })
+  results <- x$map(command = TRUE, iterate = list(x = c(1, 2)))
+  expect_equal(nrow(results), 2L)
+})
+
+crew_test("map() does not need an empty controller", {
+  skip_on_cran()
+  skip_on_os("windows")
+  x <- crew_controller_local(
+    workers = 1L,
+    seconds_idle = 360
+  )
+  on.exit({
+    x$terminate()
+    rm(x)
+    gc()
+    crew_test_sleep()
+  })
+  x$start()
+  x$push(command = TRUE)
+  x$wait(seconds_timeout = 30)
+  expect_equal(x$schedule$summary()$pushed, 0L)
+  expect_equal(x$schedule$summary()$collected, 1L)
+  results <- x$map(command = TRUE, iterate = list(x = c(1, 2)))
+  expect_equal(nrow(results), 2L)
+  expect_equal(x$schedule$summary()$pushed, 0L)
+  expect_equal(x$schedule$summary()$collected, 1L)
+})
