@@ -3,7 +3,8 @@ crew_test("crew_launcher_local() can run a task on a worker", {
   skip_on_os("windows")
   client <- crew_client(
     host = "127.0.0.1",
-    workers = 4L
+    workers = 4L,
+    tls_enable = FALSE
   )
   launcher <- crew_launcher_local(name = client$name, seconds_idle = 360)
   on.exit({
