@@ -1,7 +1,8 @@
 library(crew)
 controller <- crew_controller_local(
   workers = 20L,
-  tasks_max = 100
+  tasks_max = 100,
+  tls_enable = TRUE
 )
 controller$start()
 names <- character(0L)
